@@ -2,16 +2,18 @@
 {
 
 	'name' : 'GNU Health : Free Health and Hospital Information System',  
-    'version': '1.3.3',
+    'version': '1.4.0',
 	'author' : 'GNU Solidario',
 	'email' : 'health@gnusolidario.org',
 	'website' : "http://health.gnu.org",
     'depends' : ['ir', 'res', 'product', 'party', 'company'],
     'name_es_ES': 'GNU Health : Sistema Libre de Gestión Hospitalaria y de Salud',
-    'translation': ['es_ES.csv'],
+    'translation': [
+        'locale/es_ES.po',
+    ],
 
 	"xml" : ["health_view.xml","data/medicament_categories.xml",
-        "data/WHO_list_of_essential_medicines.xml","data/WHO_medicaments.xml",
+        "data/WHO_products.xml","data/WHO_list_of_essential_medicines.xml",
         "data/health_specialties.xml","data/ethnic_groups.xml",
         "data/occupations.xml","data/dose_units.xml",
         "data/drug_administration_routes.xml","data/medicament_form.xml",
