@@ -1,7 +1,7 @@
 # -*- encoding: utf-8 -*-
 {
     'name': 'GNU Health : Genetics',
-    'version': '1.3.3',
+    'version': '1.4.0',
     'author': 'GNU Solidario',
     'email': 'health@gnusolidario.org',
     'website': 'http://health.gnu.org',
@@ -10,7 +10,9 @@
         'health',
     ],
     'name_es_ES': 'GNU Health : Genética',
-    'translation': ['es_ES.csv'],
+    'translation': [
+        'locale/es_ES.po',
+    ],
     
     'description': '''
 
